<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Erro</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation type="unfinished">Falha ao iniciar o servidor</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Falha ao salvar o recorde no arquivo %1</translation>
    </message>
    <message>
        <source>new</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Por favor selecione um entrada na lista acima</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>pt_BR.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation type="unfinished">Falha ao abrir o arquivo de demonstração %1</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temas</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>Endereço IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation type="unfinished">O servidor nao foi encontrado. Por favor, verifique o nome do servidor e as configurações de porta.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Conexão negada</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation type="unfinished">SDL_ttf retornou um erro enquanto renderizava texo, o mais provável é que esse esteja relacionado a um problema na freetype2. Recomendamos que você atualize sua biblioteca freetype.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Clear Accounts Cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;p&gt;O prêmio de melhor disparo foi ganho por &lt;b&gt;%1&lt;/b&gt; , com &lt;b&gt;%2&lt;/b&gt; pontos.&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Começar</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Por favor selecione o servidor na lista acima</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Official server</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Nova equipe</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Editar equipe</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation type="unfinished">Especifique o novo nome do arquivo:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Não foi possível renomear para</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Não foi possível excluir o arquivo</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Por favor selecione uma entrada da lista</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Erro</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Excluir</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ban</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Follow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Fullscreen</source>
        <translation>Tela cheia</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Habilitar sons</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Mostrar FPS (Performance)</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Mostrar dano de maneira alternativa</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Habilitar música</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Interface em tela cheia</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check for updates at startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation type="unfinished">gerando mapa...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Humano</translation>
    </message>
    <message>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mission</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Membros da equipe</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Associação de teclas</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Forte</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Equipes</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Opções de audi e gráficos</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Armas</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Jogo em ree</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Equipes em jogo</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>Este programa é distribuido sob a GNU General Public License</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation type="unfinished">Desenvolvedores:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Gráficos:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation type="unfinished">Traduções:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation type="unfinished">Agradecimentos especiais:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Armas</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished">Anfitrião:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished">Porta:</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolução</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>Limite de FPS</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation type="unfinished">Apelido de rede</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation type="unfinished">Nome do servidor:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation type="unfinished">Porta do servidor:</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation type="unfinished">Sons:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mines Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation type="unfinished">Esquema de jogo</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Locale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>sem nome</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation type="unfinished">A conexão com o servidor foi perdida</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Não foi possível abrir diretório de dados:
%1
Por favor verifique sua instalação</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Armas</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation>Não foi possível editar o set de armas padrão</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation>Não foi possível excluir o set padrão de armas</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation type="unfinished">Realmente deseja remover este set de armas?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Não foi possível criar o diretório %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Go!</source>
        <translation type="unfinished">Avançar!</translation>
    </message>
    <message>
        <source>default</source>
        <translation>pre-determinado</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Iniciar servidor</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Especificar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Visualizar Demonstração</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Load</source>
        <translation type="unfinished">Carregar</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Configuração</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Map</source>
        <translation type="unfinished">Mapa</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="unfinished">Armas</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delays</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Não foi possível iniciar o servidor: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Não foi possível iniciar o motor: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Karma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>King</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>acima</translation>
    </message>
    <message>
        <source>left</source>
        <translation>esquerda</translation>
    </message>
    <message>
        <source>right</source>
        <translation>direita</translation>
    </message>
    <message>
        <source>down</source>
        <translation>abaixo</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>atacar</translation>
    </message>
    <message>
        <source>put</source>
        <translation>usar</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>trocar</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>encontrar porco espinho</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>menu de munições</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>posição 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>posição 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>posição 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>posição 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>posição 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>posição 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation type="unfinished">posição 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation type="unfinished">posição 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>posição 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>temporizador 1 seg</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>temporizador 2 seg</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>temporizador 3 seg</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>temporizador 4 seg</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>temporizador 5 seg</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>pausa</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>diminuir volume</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>aumentar volume</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>alterar modo</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>capturar</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>informação dos
porcos espinho</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>sair</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>bate-papo</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>histórico de bate-papo</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>confirmação</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>long jump</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>high jump</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Outros</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Escape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Equals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPad</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
